@@ -8,19 +8,19 @@ from bgeditor.dao import MusicHelper
 from PIL import Image
 import numpy as np
 import requests, time
-from bgeditor.dao.FFmpeg import create_suource_can_loop_path, create_loop, create_loop_audio, create_video_audio
+from bgeditor.dao.FFmpeg import create_suource_can_loop_path, create_loop, create_loop_audio, create_video_audio, merge_intro_outro
 from proglog import ProgressBarLogger
 from bgeditor.common.utils import get_dir
 import uuid
 import math
 from moviepy.video.fx import make_loopable
 class MyBarLogger(ProgressBarLogger):
-    def __init__(self,job_id):
+    def __init__(self,job_id, mf_server):
       self.is_final_vid=False
       self.old_index_frame=0
       self.start_count_time_30=0
       self.job_id=job_id
-      self.MF_SERVER= "http://api-magicframe.automusic.win/"
+      self.MF_SERVER= mf_server
       super().__init__()
 
     def update_progress(self, total, index, rate):
@@ -51,11 +51,12 @@ class MyBarLogger(ProgressBarLogger):
             self.update_progress(self.bars[bar]['total'], self.bars[bar]['index'], rate)
             self.start_count_time_30= time.time()
 
-def create_video(list_comp_data, path_video, job_id):
+def create_video(list_comp_data, path_video, job_id, mf_server):
     print('get list')
     arr_comps=[]
     for comp_data in list_comp_data:
         comp_data["job_id"]=job_id
+        comp_data["mf_server"] = mf_server
         arr_comps.append(Component.convert(comp_data))
     arr_comps.sort(key=lambda obj: obj.index)
     arr_composite = []
@@ -64,11 +65,15 @@ def create_video(list_comp_data, path_video, job_id):
     is_compilation=False
     audio_compilation_path=None
     cnt_effect_vid=0
+    inoutroComp = None
     for comp in arr_comps:
         if comp.type=="compilation":
             is_compilation=True
             audio_compilation_path=comp.get_audio()
             continue
+        if comp.type=="inoutro":
+            inoutroComp = comp
+            continue
         if comp.type=="video":
             cnt_effect_vid += 1
         if comp.type == "element":
@@ -78,15 +83,16 @@ def create_video(list_comp_data, path_video, job_id):
             arr_composite = [comp.make()]
         else:
             arr_composite.append(comp.make())
+
         if comp.duration + comp.start_time > max_duration:
             max_duration = comp.duration + comp.start_time
         if comp.real_duration + comp.start_time > max_real_duration:
             max_real_duration = comp.real_duration + comp.start_time
 
-    logger = MyBarLogger(job_id)
+    logger = MyBarLogger(job_id, mf_server)
     if not is_compilation:
         final_clip = CompositeVideoClip(arr_composite).subclip(0, max_duration)
-        final_clip.write_videofile(path_video, fps=24, codec='libx264', logger=logger)
+        final_clip.write_videofile(path_video, bitrate='4M', fps=24, codec='libx264', logger=logger)
         final_clip.close()
     else:
         if audio_compilation_path is None:
@@ -131,13 +137,20 @@ def create_video(list_comp_data, path_video, job_id):
             pass
         audio_compilation.close()
         create_video_audio(final_clip_path, audio_compilation_path, path_video)
+    final_vid = VideoFileClip(path_video)
+    duration_f = final_vid.duration
+    final_vid.close()
+    if duration_f > 0 and inoutroComp is not None:
+        path_video = merge_intro_outro(path_video, inoutroComp.intro, inoutroComp.outro)
     for comp in arr_comps:
         comp.close()
+    return path_video
 
 
 class Component:
     def __init__(self, json_data):
         self.job_id=json_data['job_id']
+        self.mf_server=json_data['mf_server']
         self.index = json_data['index']
         self.position = json_data['position']
         self.start_time = json_data['startTime']
@@ -163,6 +176,8 @@ class Component:
             return ElementComp(json_data)
         if json_data['type'] == "compilation":
             return CompilationComp(json_data)
+        if json_data['type'] == "inoutro":
+            return InOutroComp(json_data)
     def setup(self):
         print('setup')
     def order(self):
@@ -208,6 +223,17 @@ class Component:
                 self.audio_moviepy.close()
         except :
             pass
+
+class InOutroComp(Component):
+    def __init__(self, json_data):
+        super().__init__(json_data)
+        self.intro =None
+        self.outro =None
+        if json_data['intro'] and len(json_data['intro']) > 0:
+            self.intro =  download_file(json_data['intro'], ext=json_data['ext'])
+        if json_data['outro'] and len(json_data['outro']) > 0:
+            self.outro = download_file(json_data['outro'], ext=json_data['ext'])
+
 class CompilationComp(Component):
     def __init__(self, json_data):
         super().__init__(json_data)
@@ -215,7 +241,7 @@ class CompilationComp(Component):
         self.music_data = json_data['music_data']
 
     def get_audio(self):
-        return MusicHelper.create_compilation_songs(self.music_data, self.job_id)
+        return MusicHelper.create_compilation_songs(self.music_data, self.job_id, self.mf_server)
 
 
 class ElementComp(Component):
@@ -312,7 +338,7 @@ class VideoComp(Component):
             self.kind = "canva"
     def get_clip(self):
         if self.isLoop and self.ext != "gif":
-            obj = requests.get("http://api-magicframe.automusic.win/resource/get-md5/"+self.kind+"/"+self.md5).json()
+            obj = requests.get(self.mf_server+"resource/get-md5/"+self.kind+"/"+self.md5).json()
             if "id" in obj:
                 if "loop_link" in obj and obj['loop_link'] is not None and "gdrive" in obj['loop_link']:
                     self.video_path = download_file(obj['loop_link'], ext=self.ext)
@@ -323,7 +349,7 @@ class VideoComp(Component):
                         raise Exception(" Error create source loop")
                     else:
                         drive_id = upload_file(path_loop)
-                    requests.get("http://api-magicframe.automusic.win/resource/set-md5/"+self.kind+"/" + self.md5+"/"+ drive_id)
+                    requests.get(self.mf_server+"resource/set-md5/"+self.kind+"/" + self.md5+"/"+ drive_id)
                     self.video_path = path_loop
         else:
             self.video_path = download_file(self.video_url, ext=self.ext)
