@@ -98,6 +98,44 @@ def create_loop_audio(audio_path, loop_duration):
     except:
         pass
     return None
+
+def merge_list_video(vids, is_del=True):
+    file_merg_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4())
+    final_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-final-' + os.path.basename(vids[0])
+    file_merg = open(file_merg_path, "a")
+    arrtmp = []
+    for vid in vids:
+        tmp_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-' + os.path.basename(vid)
+        shutil.copyfile(vid, tmp_clip_path)
+        if is_del:
+            os.remove(vid)
+        file_merg.write("file '%s'\n" % os.path.basename(tmp_clip_path))
+        arrtmp.append(tmp_clip_path)
+    file_merg.close()
+    cmd = "ffmpeg -y -f concat -safe 0 -i \"%s\" -codec copy \"%s\"" % (file_merg_path, final_clip_path)
+    os.system(cmd)
+    os.remove(file_merg_path)
+    for item in arrtmp:
+        os.remove(item)
+    clip = VideoFileClip(final_clip_path)
+    clip_duration = clip.duration
+    clip.close()
+    if clip_duration < 1:
+        return None
+    return final_clip_path
+
+
+def merge_intro_outro(clip_path, intro = None, outro = None):
+    arrVids=[]
+    if not intro and not outro:
+        return clip_path
+    if intro:
+        arrVids.append(intro)
+    arrVids.append(clip_path)
+    if outro:
+        arrVids.append(outro)
+    return merge_list_video(arrVids, True)
+
 def create_video_audio(clip_path, audio_path, rs_path=None, is_del=True):
     try:
         tmp_clip_path_z=rs_path
