@@ -3,6 +3,7 @@ from bgeditor.common.utils import get_dir, download_file,normal_audio
 from bgeditor.dao.FFmpeg import create_loop_audio_times
 import uuid,json, shutil,os
 from moviepy.editor import *
+import urllib
 def download_audio(url,ext='mp3'):
     file_name = str(uuid.uuid4()) + "." + ext
     rs = get_dir('download') + file_name
@@ -13,7 +14,7 @@ def download_audio(url,ext='mp3'):
     with youtube_dl.YoutubeDL(ydl_opts) as ydl:
         ydl.download([url])
     return rs
-def create_compilation_songs(data, job_id):
+def create_compilation_songs(data, job_id, mf_server):
     #[{"type":3,"url":"","repeat":1}]
     #3: youtube_video
     #7: deezer
@@ -43,7 +44,7 @@ def create_compilation_songs(data, job_id):
                         song['local'] = download_file(song_info['url_128'])
                 if arr_tmp[0] == "automusic" and arr_tmp[1] == "source":
                     arr_song_info = requests.get("http://source.automusic.win/config/f-retrieve/"+arr_tmp[2] +
-                                                 f"?jobid={job_id}", timeout=600).json()
+                                                 f"?jobid={job_id}&mfs={urllib.parse.quote_plus(mf_server)}", timeout=600).json()
                     for song_info in arr_song_info:
                         arr_songs.append({"uri":"direct:track:"+song_info['url_128'], "repeat":1})
 
@@ -58,8 +59,7 @@ def create_compilation_songs(data, job_id):
                     continue
                     pass
 
-                if len(arr_songs) > 1:
-                    song['local']=normal_audio(song['local'])
+                song['local']=normal_audio(song['local'])
                 if song['repeat'] > 1:
                     song['local']= create_loop_audio_times(song['local'], song['repeat'])
 
@@ -74,14 +74,18 @@ def create_compilation_songs(data, job_id):
             except:
                 pass
         file_merg.close()
-        cmd = "ffmpeg -y -f concat -safe 0 -i \"%s\" -codec copy \"%s\"" % (file_merg_path, final_clip_path)
-        os.system(cmd)
-        os.remove(file_merg_path)
-        for song in arr_songs:
-            try:
-                os.remove(song['local'])
-            except:
-                pass
+        if cnt_song>1:
+            cmd = "ffmpeg -y -f concat -safe 0 -i \"%s\" -codec copy \"%s\"" % (file_merg_path, final_clip_path)
+            os.system(cmd)
+            os.remove(file_merg_path)
+            for song in arr_songs:
+                try:
+                    os.remove(song['local'])
+                except:
+                    pass
+        else:
+            if cnt_song ==1:
+                return arr_songs[0]['local']
     except:
         pass
     if cnt_song == 0:
